==> flutter_conscent_plugin-0.2.4.tar.gz: lib/passesWebviews.dart <==
// ignore_for_file: file_names
import 'dart:convert';
import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';
import '../Model/APIMode.dart';
import 'ConscentInitializer.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppsss(),
    ),
  );
}

class WebViewAppsss extends StatefulWidget {
  const WebViewAppsss({super.key});

  @override
  State<WebViewAppsss> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewAppsss> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      dataMain = jsonDecode(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('dev sessionnnnnnnnnnnnn id');
      print(prefs.getString('sessionId'));
      String sessionId = dataMain['sessionId'].toString();
      prefs.setString('sessionId', sessionId);
      print("dataMain");
      print(dataMain);
      print("dataMain");
      CircularProgressIndicator();
      return sessionId;
      // Navigator.pop(context,{
      //   "sessionId":dataMain['sessionId']
      // });
    }
    return '';
  }

  dynamic dataMains;
  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      dataMains = jsonDecode(response.body);
      var responseString = response.body;

      /*  if (dataMains != null && dataMains['signature'] != null) {
        showContent = true;
      } else {
        showContent = false;
      }
      String id = contentAccessesDtapostFromJson(responseString).signature;
      final prefs = await SharedPreferences.getInstance();*/
      Navigator.pop(context, {"response": responseString});
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas(ConscentInitializer.mClientId.toString(),
                ConscentInitializer.mContentId.toString(), sessionId);
          }
        });
  }

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    // getLoginChallengeId();
    var flutterWebViewPlugin;

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  //'https://conscent.netlify.app/overlay?clientId=5f92a62013332e0f667794dc&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                  '${APIMode.SERVICE_BASE_URL}/overlay?purchaseMode=PASS&loginChallenge=$loginId&clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                //  getSessionID(loginId.toString());
                //   submitDatas(clientId.text, clientContentId.text,sessionId);
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');
                //    javascriptChannels: <JavascriptChannel>{_javascriptChannel()};
                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){

                  Navigator.pop(context);

                  //  navigator?.pop();
                  //  Navigator.pop(context, true);
                  //Navigator.popAndPushNamed(context, '/Subscribe');
                  // Navigator.of(context).popUntil((route) => route.isFirst);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}

==> flutter_conscent_plugin-0.3.0.tar.gz: lib/passesWebviews.dart <==
// import 'package:flutter/material.dart';
// import 'package:webview_flutter/webview_flutter.dart';

// void main() => runApp(MyAppgg());

// class MyAppgg extends StatelessWidget {

// const MyAppgg({super.key});

//   @override
//   Widget build(BuildContext context) {
//     return MaterialApp(home: Scaffold(body: WebViewLoad()));
//   }
// }

// class WebViewLoad extends StatefulWidget {
//   WebViewLoadUI createState() => WebViewLoadUI();
// }

// class WebViewLoadUI extends State<WebViewLoad> {

import 'package:flutter/material.dart';
import 'package:http/http.dart' as http;
import 'package:shared_preferences/shared_preferences.dart';
import 'package:webview_flutter/webview_flutter.dart';

import 'ConscentInitializer.dart';
import 'ConscentMethods.dart';
import 'Model/APIMode.dart';
import 'Model/loginChallengeget.dart';
//import 'package:flutter_new/defaultSubscribtion.dart';

void main() {
  runApp(
    const MaterialApp(
      home: WebViewAppsss(),
    ),
  );
}

class WebViewAppsss extends StatefulWidget {
  const WebViewAppsss({super.key});

  @override
  State<WebViewAppsss> createState() => _WebViewAppState();
}

class _WebViewAppState extends State<WebViewAppsss> {
  String? loginId;
  // String? sessionId;

  bool showContent = false;
  bool isLoaded = false;
  final clientId = TextEditingController();
  final clientContentId = TextEditingController();
  // final sessionId = TextEditingController();

  @override
  void initState() {
    if (mounted) {
      getLoginChallengeId();
    }
    super.initState();
  }

  // dynamic dataMain;
  getLoginChallengeId() async {
    final prefs = await SharedPreferences.getInstance();
    loginId = prefs.getString('loginID');
    print(loginId.toString());
    getSessionID(loginId.toString());
    setState(() {});
  }

  Future<String> getSessionID(String loginId) async {
    print('getSessionId------');
    var uri = Uri.parse('${APIMode.BASE_URL}api/v1/login-challenge/$loginId');
    print(uri);
    var response = await http.get(uri);
    if (response.statusCode == 200) {
      LoginChallengeget loginChallengeget =
          loginChallengegetFromJson(response.body);
      final prefs = await SharedPreferences.getInstance();
      print('dev sessionnnnnnnnnnnnn id');
      print('WebViewAppsss sessionId ${prefs.getString('sessionId')}');
      String sessionId = loginChallengeget.sessionId.toString();
      prefs.setString('sessionId', sessionId);
      CircularProgressIndicator();
      return sessionId;
    } else {
      ConscentMethods().onPluginError(response.body);
    }
    return '';
  }

  Future<void> submitDatas(
      String clientId, String clientContentId, String sessionId) async {
    print('sessionId xyz= $sessionId');
    var response = await http
        .post(Uri.parse('${APIMode.BASE_URL}api/v1/content/access'), body: {
      "clientId": '${ConscentInitializer.mClientId}',
      "clientContentId": '${ConscentInitializer.mContentId}',
      "sessionId": sessionId,
    });
    print('-------------------------------------------------------');
    print('${response.body}---- status---${response.statusCode}');

    if (response.statusCode == 201) {
      var responseString = response.body;
      Navigator.pop(context, {"response": responseString});
    } else {
      ConscentMethods().onPluginError(response.body);
    }
  }

  JavascriptChannel _javascriptChannel() {
    print('javascript');
    return JavascriptChannel(
        name: 'LOGINCHALLENGE',
        onMessageReceived: (JavascriptMessage message) async {
          print(message.message);
          if (message.message == 'loginSuccess') {
            CircularProgressIndicator();
            print('javascript----------');
            String sessionId = await getSessionID(loginId!);
            submitDatas(ConscentInitializer.mClientId.toString(),
                ConscentInitializer.mContentId.toString(), sessionId);
          }
        });
  }

  // ... to here.

  @override
  Widget build(BuildContext context) {
    javascriptChannels:
    <JavascriptChannel>{_javascriptChannel()};
    // getLoginChallengeId();
    var flutterWebViewPlugin;
    print(loginId);
    print('kunallllllll');

    return Scaffold(
      appBar: AppBar(
        title: const Text('Conscent'),
      ),
      body: loginId != null
          ? WebView(
              initialUrl:
                  //'https://conscent.netlify.app/overlay?clientId=5f92a62013332e0f667794dc&clientContentId=Client-Story-Id-1&loginChallenge=$loginId',
                  '${APIMode.SERVICE_BASE_URL}/overlay?purchaseMode=PASS&loginChallenge=$loginId&clientId=${ConscentInitializer.mClientId}&clientContentId=${ConscentInitializer.mContentId}',
              javascriptMode: JavascriptMode.unrestricted,
              onProgress: (int progress) async {
                //  getSessionID(loginId.toString());
                //   submitDatas(clientId.text, clientContentId.text,sessionId);
                javascriptChannels:
                <JavascriptChannel>{_javascriptChannel()};
                print('WebView is loading (progress : $progress%)');
              },
              onWebViewCreated: (controller) {
                print('---onWebViewCreated----${controller.currentUrl()}');
              },
              navigationDelegate: (NavigationRequest request) {
                print('----navigation delegate---${request.url}');
                //    javascriptChannels: <JavascriptChannel>{_javascriptChannel()};
                if (request.url.startsWith('https://xyz.zyz')) {
                  print('APIU CALL FIRST');

                  getSessionID(loginId!);

                  return NavigationDecision.prevent;
                } else if (request.url.startsWith(
                    '${APIMode.SERVICE_BASE_URL}/?csc-tierId=619b7f6cfbacc96bd8fb232a')) {
                  //      .startsWith('https://conscentsss.com/?csc-tierId=${widget.tiersId})')){

                  Navigator.pop(context);

                  //  navigator?.pop();
                  //  Navigator.pop(context, true);
                  //Navigator.popAndPushNamed(context, '/Subscribe');
                  // Navigator.of(context).popUntil((route) => route.isFirst);
                }

                print('allowing navigation to $request');
                return NavigationDecision.navigate;
              },
              onPageStarted: (String url) {
                print('Page started loading: $url');
              },
              onPageFinished: (String url) {
                print('Page finished loading: $url');
                print('urllllllllllllllllllll: $url');
              },
              javascriptChannels: <JavascriptChannel>{_javascriptChannel()},
            )
          : Center(child: CircularProgressIndicator()),
    );
  }
}
